import hy.macros
import requests
from anarcute import *

hy.macros.require('anarcute.lib', None, assignments='ALL', prefix='')


class GT(object):
    """Google translate"""

    def __init__(self, key):
        self.key = key
        self.api = 'https://translation.googleapis.com/language/translate/v2'
        return None

    def translate(self, source, target, q, format='text', model=None):
        params = {'key': self.key, 'q': q, 'source':
            source, 'target': target, 'format': format, 'model': model}
        return requests.get(self.api, params).json()


class GS(object):
    """Google Custom Search Engine"""

    def __init__(self, cx, key):
        self.api = 'https://www.googleapis.com/customsearch/v1/siterestrict'
        self.cx = cx
        self.key = key

    #start = number of first item
    #by default it returns search result with 10 searches
    def search(self, q, follow=True, TIMEOUT=10, start=1):
        params = {'q': q, 'cx': self.cx, 'key':
            self.key, 'start': start}
        res = requests.get(self.api, params=params, timeout=TIMEOUT).json()

        if (not 'items' in res and follow and 'spelling' in res and
                'correctedQuery' in res['spelling']):
            corrected = res['spelling']['correctedQuery']
            print('REDIRECT from', q, 'to', corrected)
            return self.search(corrected, follow=True, start=start, TIMEOUT=TIMEOUT)
        else:
            return res

    # start = number of first item
    # end = number of last item
    # by default Google will return 100 items
    def items(self, q, start=1, end=None):
        r = self.search(q, start=start)
        try:
            items = r['items']
        except Exception:
            items = []
        if 'queries' in r and 'nextPage' in r['queries']\
                and r['queries']['nextPage']\
                and (not end or end < len(items)):
            return items + self.items(q, start=r['queries']['nextPage'][0][
            'startIndex'])
        else:
            return items




#read functions from bottom to up
import sys,json

def sort_by_values(obj,reverse=True):
	return dict(sorted(obj.items(),key=lambda key_value:key_value[1],reverse=reverse)) if obj else obj
sort_by_value=sort_by_values

def weight_in(subset,mainset):
	res={}
	for k,v in subset.items():
		if k in mainset:
			res[k]=subset[k]/mainset[k]
	return res

def freq(arr):
	res={}
	for word in arr:
		if word in res:
			res[word]+=1
		else:
			res[word]=1
	return res
def normalize(res):
	total=sum(v for k,v in res.items())
	for word in res:
		res[word]=res[word]/total
	return res

def vectorize(text,permitted=None):
	if not permitted:
		permitted="qwertyuiopasdfghjklzxcvbnm"
		permitted+=permitted.upper()
	arr=list(map(lambda c: c if c in permitted else " ",list(text.lower())))
	text="".join(arr)
	while "  " in text:
		text=text.replace("  "," ")
	arr=text.split(' ')
	return normalize(freq(arr))

def tf_idf(context,text):
	return weight_in(normalize(context) if type(context)==dict else vectorize(context),normalize(text) if type(text)==dict else vectorize(text))

if __name__ == "__main__":
	text=open(sys.argv[2],"r+").read() if sys.argv[1].endswith(".txt") else sys.argv[1]
	context=open(sys.argv[1],"r+").read() if sys.argv[1].endswith(".txt") else sys.argv[2]
	print(json.dumps(sort_by_values(tf_idf(context,text),reverse=True),indent=4))

